﻿const { app, BrowserWindow, ipcMain, systemPreferences } = require("electron");
const path = require("path");
const { electron } = require("process");

// Check and apply for device permissions: microphone, camera, screen recording
async function checkAndApplyDeviceAccessPrivilege() {
  const cameraPrivilege = systemPreferences.getMediaAccessStatus("camera");
  console.log(
    `checkAndApplyDeviceAccessPrivilege before apply cameraPrivilege: ${cameraPrivilege}`
  );
  if (cameraPrivilege !== "granted") {
    if (process.platform === "darwin") {
      await systemPreferences.askForMediaAccess("camera");
    }
  }

  const micPrivilege = systemPreferences.getMediaAccessStatus("microphone");
  console.log(`checkAndApplyDeviceAccessPrivilege before apply micPrivilege: ${micPrivilege}`);
  if (micPrivilege !== "granted") {
    if (process.platform === "darwin") {
      await systemPreferences.askForMediaAccess("microphone");
    }
  }

  const screenPrivilege = systemPreferences.getMediaAccessStatus("screen");
  console.log(
    `checkAndApplyDeviceAccessPrivilege before apply screenPrivilege: ${screenPrivilege}`
  );
}

// Create the main view
function createWindow() {
  const windowOptions = {
    width: 1080,
    minWidth: 680,
    height: 840,
    webPreferences: {
      webSecurity: false,
      nodeIntegration: true,
      contextIsolation: false,
      preload: path.join(__dirname, "preload.js"),
      enableRemoteModule: true,
    },
  };
  const mainWindow = new BrowserWindow(windowOptions);
  // load view
  mainWindow.loadFile("index.html");
}

function initApp() {
  app.whenReady().then(async () => {
    await checkAndApplyDeviceAccessPrivilege();
    createWindow();
    app.on("activate", () => {
      if (BrowserWindow.getAllWindows().length === 0) {
        createWindow();
      }
    });
  });

  app.on("window-all-closed", () => {
    // if (process.platform !== "darwin") app.quit();
    app.quit();
  });
}

function main() {
  initApp();
}

main();
